# phpoci8.spec
# Builds the latest PHP OCI8 extension on top of PHP 5.3

# PHP & API versions for cross-checking purposes
%define apiver 20090626
%define zendver 20090626

%define ORACLE11g_HOME /opt/app/oracle/product/11.2.0/db_1

# The version of the OCI8 PECL extension being installed, ie. taken
# from the filename oci8-a.b.c.tgz
%define oci8peclver 1.4.5

# Install location of files
%define basefiledir %{_libdir}/php/modules

# PHP Package release that this OCI8 extension can be used with
%define phprelease 1

Summary: The PHP OCI8 Extension module for PHP applications using the Oracle database
Name: php-oci8
Group: Development/Languages
Version: 5.3.2
Release: 1.1%{?dist}
License: The PHP License v3.01
URL: http://www.php.net/

Source0: http://pecl.php.net/get/oci8-%{oci8peclver}.tgz
Source100: libdummy.c

BuildRoot: %{_tmppath}/%{name}-root

%description
The php-oci8 package contains a dynamic shared object (DSO) for the
Apache Web server, CGI and command line PHP.  OCI8 is an extension for
Oracle Database access.  PHP is an HTML-embedded scripting language.
If you need Oracle support for PHP applications, you can install this
package and the php package.

Requires: php-common >= %{version}
Requires: libaio >= 0.3.105
BuildRequires: php-devel >= %{version}-%{phprelease}
BuildRequires: fileutils, file >= 4.0, libtool >= 1.4.3, gcc-c++
Provides: php_database, php-oci, mod_php = %{version}-%{phprelease}
AutoReqProv: No

%prep
rm -rf oci8-%{oci8peclver} oci8-%{oci8peclver}
tar -zxf %{_sourcedir}/oci8-%{oci8peclver}.tgz

# Safety check for API version change.
vapi=`phpize -v | sed -n '/PHP Api Version:/{s/.* //;p}'`
if test "x${vapi}" != "x%{apiver}"; then
   : Error: Upstream API version is now ${vapi}, expecting %{apiver}.
   : Update the apiver macro and rebuild.
   exit 1
fi

# Safety check for Zend API version change.
vzend=`phpize -v | sed -n '/Zend Module Api No:/{s/^[^0-9]*//;p;}'`
if test "x${vzend}" != "x%{zendver}"; then
   : Error: Upstream Zend module ABI version is now ${vzend}, expecting %{zendver}.
   : Update the zendver macro and rebuild.
   exit 1
fi

%build
pushd oci8-%{oci8peclver}
phpize

CFLAGS="$RPM_OPT_FLAGS -fno-strict-aliasing -Wno-pointer-sign"
export CFLAGS

# Build the oci8 extension
%configure --with-oci8=shared,%{ORACLE11g_HOME}
if test $? != 0; then
  tail -500 config.log
  : configure failed
  exit 1
fi

make %{?_smp_mflags}

popd

%install
[ "$RPM_BUILD_ROOT" != "/" ] && rm -rf $RPM_BUILD_ROOT
INSTALL_DIR=$RPM_BUILD_ROOT%{basefiledir}

install -m 755 -d $INSTALL_DIR/

# Install everything from the earlier OCI8 build
pushd oci8-%{oci8peclver}
make install INSTALL_ROOT=$RPM_BUILD_ROOT
popd

gcc -shared -fPIC -Wl,-soname,libclntsh.so.11.1 %{SOURCE100} -o $RPM_BUILD_ROOT/%{_libdir}/libclntsh.so.11.1

# Generate stub .ini file
mkdir -p $RPM_BUILD_ROOT/etc
mkdir -p $RPM_BUILD_ROOT/etc/php.d
cat > $RPM_BUILD_ROOT/etc/php.d/oci8.ini <<EOF
; Enable OCI8 extension module
extension=oci8.so

[OCI8]

; Connection: Enables privileged connections using external
; credentials (OCI_SYSOPER, OCI_SYSDBA)
;oci8.privileged_connect = Off

; Connection: The maximum number of persistent OCI8 connections per
; process. Using -1 means no limit.
;oci8.max_persistent = -1

; Connection: The maximum number of seconds a process is allowed to
; maintain an idle persistent connection. Using -1 means idle
; persistent connections will be maintained forever.
;oci8.persistent_timeout = -1

; Connection: The number of seconds that must pass before issuing a
; ping during oci_pconnect() to check the connection validity. When
; set to 0, each oci_pconnect() will cause a ping. Using -1 disables
; pings completely.
;oci8.ping_interval = 60

; Connection: Set this to a user chosen connection class to be used
; for all pooled server requests with Oracle 11g Database Resident
; Connection Pooling (DRCP).  To use DRCP, this value should be set to
; the same string for all web servers running the same application,
; the database pool must be configured, and the connection string must
; specify to use a pooled server.
;oci8.connection_class =

; High Availability: Using On lets PHP receive Fast Application
; Notification (FAN) events generated when a database node fails. The
; database must also be configured to post FAN events.
;oci8.events = Off

; Tuning: This option enables statement caching, and specifies how
; many statements to cache. Using 0 disables statement caching.
;oci8.statement_cache_size = 20

; Tuning: Enables statement prefetching and sets the default number of
; rows that will be fetched automatically after statement execution.
;oci8.default_prefetch = 100

; Compatibility. Using On means oci_close() will not close
; oci_connect() and oci_new_connect() connections.
;oci8.old_oci_close_semantics = Off

EOF

%clean
[ "x${RPM_BUILD_ROOT}" != "x/" ] && rm -rf $RPM_BUILD_ROOT

%files 
%attr(755,root,root) %{basefiledir}/oci8.so
%config(noreplace) %attr(644,root,root) %{_sysconfdir}/php.d/oci8.ini
%{_libdir}/libclntsh.so.11.1


%changelog 
* Mon Aug 29 2011 Mika Kamei <mika.kamei@miraclelinux.com> 5.3.2-1.1%{?dist}
- don't divide into two packages (11gR1, 11gR2)
- install oci8.so into /usr/lib/php/modules, install oci8.ini into /etc/php.d
- add dummy libclntsh.so.11.1

* Tue Aug 2 2011 Mika Kamei <mika.kamei@miraclelinux.com> 5.3.2-1.%{?dist}
- Use PHP 5.3.2 for AXS4
- remove BuildRequires for oracle-instant-clientbasic 

* Thu Jan 6 2011 Christopher Jones <christopher.jones@oracle.com> 5.3.5
- Use PHP 5.3.5

* Mon Nov 15 2010 Christopher Jones <christopher.jones@oracle.com>
- Use OCI8 1.4.4

* Thu Aug 12 2010 Christopher Jones <christopher.jones@oracle.com>
- Use OCI8 1.4.3

* Mon Mar 15 2010 Christopher Jones <christopher.jones@oracle.com>
- Update tarball to 1.4.1 version
- Build with Oracle client 11.2

* Mon Nov 1 2009 Christopher Jones <christopher.jones@oracle.com> 5.2.11
- Use PHP 5.2.11

* Mon Jun 22 2009 Christopher Jones <christopher.jones@oracle.com> 5.2.10
- Use PHP 5.2.10

* Wed Apr 28 2009 Christopher Jones <christopher.jones@oracle.com> 5.2.9
- Rename as php52-*

* Mon Mar 16 2009 Christopher Jones <christopher.jones@oracle.com> 5.2.9
- Update for OCI8 1.3.5 and 5.2.9

* Mon Dec 15 2008 Christopher Jones <christopher.jones@oracle.com> 5.2.8
- Update for 5.2.8

* Mon Aug 18 2008 Christopher Jones <christopher.jones@oracle.com> 5.1.6-20.el5_2.1
- Allow potential future package built with other Oracle client libraries to co-exist

* Tue Aug 08 2008 Srinivas Maturi <srinivas.maturi@oracle.com> 5.1.6-20.el5_2.1
- Update BuildRequires for oracle-instantclient-devel and Conflicts for
  oracle-instantclient-basic

* Tue Aug 05 2008 Srinivas Maturi <srinivas.maturi@oracle.com> 5.1.6-20.el5_2.1
- Update tarball to 1.3.4 version

* Fri Jul 21 2008 Srinivas Maturi <srinivas.maturi@oracle.com> 5.1.6-20.el5_2.1
- Update release to rebuild for latest errata

* Thu Jul 10 2008 Srinivas Maturi <srinivas.maturi@oracle.com> 5.1.6
- Update rpm name, add libaio as runtime dependency, remove code to run
  tests at build time

* Wed Apr 23 2008 Christopher Jones <christopher.jones@oracle.com> 5.1.6
- Build OCI8 (Spec file based on EL 5.1 php.spec)

